@@ -17,7 +17,7 @@
 
 blocklistFile = '/home/user/MyDocs/BlockedCallers.txt'
 daemonFile = '/opt/pycallblocker/callblocker-daemon.py'
-pidFile = '/home/user/MyDocs/tmp/pid.txt'
+pidFile = '/tmp/callblocker_pid.txt'
 
 # Это все, что нам нужно для Qt
 from PyQt4 import QtGui, QtCore
